@@ -14,7 +14,7 @@ package MCE::Core::Manager;
 use strict;
 use warnings;
 
-our $VERSION = '1.900';
+our $VERSION = '1.902';
 
 ## no critic (BuiltinFunctions::ProhibitStringyEval)
 ## no critic (TestingAndDebugging::ProhibitNoStrict)
@@ -439,7 +439,9 @@ sub _output_loop {
             return;
          }
 
-         my @_ret_a = $_input_data->($_chunk_size);
+         my @_ret_a = (ref $_input_data eq 'CODE')
+            ? $_input_data->($_chunk_size)
+            : $_input_data->();
 
          if (@_ret_a > 1 || defined $_ret_a[0]) {
             $_buf = $self->{freeze}([ @_ret_a ]);
@@ -1041,7 +1043,7 @@ MCE::Core::Manager - Core methods for the manager process
 
 =head1 VERSION
 
-This document describes MCE::Core::Manager version 1.900
+This document describes MCE::Core::Manager version 1.902
 
 =head1 DESCRIPTION
 
