@@ -11,7 +11,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized numeric );
 
-our $VERSION = '1.879';
+our $VERSION = '1.902';
 
 ## no critic (BuiltinFunctions::ProhibitStringyEval)
 
@@ -25,7 +25,11 @@ my ($_is_winenv, $_zero_bytes, %_sock_ready);
 
 BEGIN {
    $_is_winenv  = ( $^O =~ /mswin|mingw|msys|cygwin/i ) ? 1 : 0;
-   $_zero_bytes = "\x00\x00\x00\x00";
+   $_zero_bytes = pack('L', 0);
+}
+
+sub CLONE {
+   %_sock_ready = ();
 }
 
 our $LF = "\012";  Internals::SvREADONLY($LF, 1);
@@ -57,12 +61,16 @@ sub get_ncpu {
    OS_CHECK: {
       local $_ = lc $^O;
 
-      /linux/ && do {
+      /linux|android/ && do {
          my ( $count, $fh );
          if ( open $fh, '<', '/proc/stat' ) {
             $count = grep { /^cpu\d/ } <$fh>;
             close $fh;
          }
+         elsif ( open $fh, '<', '/proc/cpuinfo' ) {
+            $count = grep { /^processor/ } <$fh>;
+            close $fh;
+         }
          $ncpu = $count if $count;
          last OS_CHECK;
       };
@@ -240,7 +248,7 @@ sub _sock_pair {
             AF_UNIX, Socket::SOCK_STREAM(), 0 ) or die "socketpair: $!\n";
       }
 
-      if ($^O ne 'aix' && $^O ne 'linux') {
+      if ($^O !~ /aix|linux|android/) {
          setsockopt($_obj->{$_r_sock}[$_i], SOL_SOCKET, SO_SNDBUF, int $_size);
          setsockopt($_obj->{$_r_sock}[$_i], SOL_SOCKET, SO_RCVBUF, int $_size);
          setsockopt($_obj->{$_w_sock}[$_i], SOL_SOCKET, SO_SNDBUF, int $_size);
@@ -263,7 +271,7 @@ sub _sock_pair {
             AF_UNIX, Socket::SOCK_STREAM(), 0 ) or die "socketpair: $!\n";
       }
 
-      if ($^O ne 'aix' && $^O ne 'linux') {
+      if ($^O !~ /aix|linux|android/) {
          setsockopt($_obj->{$_r_sock}, SOL_SOCKET, SO_SNDBUF, int $_size);
          setsockopt($_obj->{$_r_sock}, SOL_SOCKET, SO_RCVBUF, int $_size);
          setsockopt($_obj->{$_w_sock}, SOL_SOCKET, SO_SNDBUF, int $_size);
@@ -281,8 +289,7 @@ sub _sock_ready {
    my ($_socket, $_timeout) = @_;
    return '' if !defined $_timeout && $_sock_ready{"$_socket"} > 1;
 
-   my ($_delay, $_val_bytes, $_start) = (0, "\x00\x00\x00\x00", time);
-   my $_ptr_bytes = unpack('I', pack('P', $_val_bytes));
+   my ($_val_bytes, $_delay, $_start) = (pack('L', 0), 0, time);
 
    if (!defined $_timeout) {
       $_sock_ready{"$_socket"}++;
@@ -294,14 +301,14 @@ sub _sock_ready {
 
    while (1) {
       # MSWin32 FIONREAD - from winsock2.h macro
-      ioctl($_socket, 0x4004667f, $_ptr_bytes);
+      ioctl($_socket, 0x4004667f, $_val_bytes);
 
       return '' if $_val_bytes ne $_zero_bytes;
       return  1 if $_timeout && time > $_timeout;
 
       # delay after a while to not consume a CPU core
       sleep(0.015), next if $_delay;
-      $_delay = 1 if time - $_start > 0.015;
+      $_delay = 1 if time - $_start > 0.030;
    }
 }
 
@@ -362,9 +369,8 @@ sub _sysread2 {
 sub _nonblocking {
    if ($^O eq 'MSWin32') {
       # MSWin32 FIONBIO - from winsock2.h macro
-      my $nonblocking = $_[1] ? "\x00\x00\x00\x01" : "\x00\x00\x00\x00";
-
-      ioctl($_[0], 0x8004667e, unpack("I", pack('P', $nonblocking)));
+      my $nonblocking = $_[1] ? pack('L', 1) : pack('L', 0);
+      ioctl($_[0], 0x8004667e, $nonblocking);
    }
    else {
       $_[0]->blocking( $_[1] ? 0 : 1 );
@@ -429,7 +435,7 @@ MCE::Util - Utility functions
 
 =head1 VERSION
 
-This document describes MCE::Util version 1.879
+This document describes MCE::Util version 1.902
 
 =head1 SYNOPSIS
 
